/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "tft.h"

//==============================================================
// write8_a0()
// writes an 8-bit value to the TFT with the D/C line low
//
// Arguments:
//      data - 8-bit value
//==============================================================
void write8_a0(uint8 data)
{
	DC_Write(0x00); 						        // set DC line low
    SPIM_1_WriteTxData(data);         		        // send data to transmit buffer
    while (!(SPIM_1_ReadTxStatus() & 0x01)){};	    // wait for data to be sent
}

//==============================================================
// write8_a1()
// writes an 8-bit value to the TFT with the D/C line high
//
// Arguments:
//      data - 8-bit value
//==============================================================
void write8_a1(uint8 data)
{
	DC_Write(0x01); 						        // set DC line high
    SPIM_1_WriteTxData(data);                       // send data to transmit buffer
    while (!(SPIM_1_ReadTxStatus() & 0x01)){};	    // wait for data to be sent
}

//==============================================================
// writeM8_a1()
// writes multiple bytes to the TFT with the D/C line high
//
// Arguments:
//      pData - pointer to an array of 8-bit data values
//      N - the size of the array *pData
//==============================================================
void writeM8_a1(uint8 *pData, int N)
{
	DC_Write(0x01); 						        // set DC line high
    int i;
    for (i=0; i<N; i++)
    {
        SPIM_1_WriteTxData(pData[i]);               // send data to transmit buffer
        while (!(SPIM_1_ReadTxStatus() & 0x01)){};  // wait for data to be sent
    }
}

//==============================================================
// read8_a1()
// reads an 8-bit value to the TFT with the D/C line high
//==============================================================
uint8 read8_a1(void)
{
	for (;;) {}                                     // read function not implemented
};

//==============================================================
// readM8_a1()
// reads multple 8-bit values from the TFT with the D/C line high
//
// Arguments:
//      pData - an array where the read values we be stored
//      N - the number of values that will be read (also size of 
//          the array pData)
//==============================================================
void readM8_a1(uint8 *pData, int N)
{
	for (;;) {}                                     // read function not implemented
}

//==============================================================
// tftStart()
// this function must be called to initializes the TFT
//==============================================================
void tftStart(void)
{
#ifdef ILI9341
    write8_a0(0x36);         			// send Memory Access Control command
	write8_a1(0x88);
    write8_a0(0x3A);         			// send COLMOD: Pixel Format Set command
    write8_a1(0x55);
    write8_a0(0x11);         			// send Sleep Out command
    write8_a0(0x29);         			// send Display ON command
    CyDelay(250);            			// delay to allow all changes to take effect	
#endif
#ifdef ILI9225
    write8_a0(0x11);   					// set the Power Control 2 register to 0x103B
    write8_a1(0x10);
    write8_a1(0x3B);
    write8_a0(0x01);       			    // set the Driver Output Control register to 0x011C
    write8_a1(0x01);
    write8_a1(0x1C);
    write8_a0(0x02);       			    // set the LCD AC Driving Control register 0x0100
    write8_a1(0x10);
    write8_a1(0x00);
    write8_a0(0x03);       			    // set the Entry Mode register to 0x1030
    write8_a1(0x10);
    write8_a1(0x30);   
    write8_a0(0x07);       			    // set the Display Control 1 register to 0x1017
    write8_a1(0x10);
    write8_a1(0x17);
#endif
}


//==============================================================
// setWindow()
// this function defines the area of the frame memory (GRAM) that 
// the Memory Write/Write Data to GRAM functions can access
//
// Arguments:
//      x0 - upper left x-position (refered to as Start Column (SC) or Horizontal Start Address (HSA))
//      y0 - upper left y-position (refered to as Start Page (SP) or Vertical Start Address (VSA))
//      x1 - lower right x-position (refered to as End Column (EC) or Horizontal End Address (HEA))
//      y1 - lower right y-position (refered to as End Page (EP) or Vertical End Address (VEA))
//
//		------> +x
//		|
//		|	(x0, y0) ---------
//		|			 |		 |
//		|			 |		 |
//		|			 --------- (x1, y1)
//	   \/
//		+y
//==============================================================
void setWindow(uint16 x0, uint16 y0, uint16 x1, uint16 y1)
{
#ifdef ILI9341
	write8_a0(0x2A);                 	// send Column Address Set command
    write8_a1(x0 >> 8);                 // set Start Column (SC) to x0
    write8_a1(x0 & 0x00FF);
    write8_a1(x1 >> 8);                 // set End Column (EC) to x1
    write8_a1(x1 & 0x00FF);
    write8_a0(0x2B);                 	// send Page Address Set command
    write8_a1(y0 >> 8);                 // set Start Page (SP) to y0
    write8_a1(y0 & 0x00FF);
    write8_a1(y1 >> 8);                 // set End Page (EP) to y1
    write8_a1(y1 & 0x00FF);
#endif
#ifdef ILI9225
    write8_a0(0x37);   					// set the Horizontal Start Address (HSA) register
    write8_a1(x0 >> 8);                 // set HSA to x0
    write8_a1(x0 & 0x00FF);	
    write8_a0(0x36);   					// set the Horizontal End Address (HEA) register
    write8_a1(x1 >> 8);                 // set HEA to x1
    write8_a1(x1 & 0x00FF);	
    write8_a0(0x39);   					// set the Vertical Start Address (VSA) register
    write8_a1(y0 >> 8);                 // set VSA to y0
    write8_a1(y0 & 0x00FF);	
    write8_a0(0x38);   					// set the Vertical End Address (VEA) register
    write8_a1(y1 >> 8);                	// set VEA to y1
    write8_a1(y1 & 0x00FF);	
    write8_a0(0x20);   					// write to R20h, the horizontal component of the Adress Counter (AC)
    write8_a1(x0 >> 8);					// set the horizontal starting position to x0
    write8_a1(x0 & 0x00FF);
    write8_a0(0x21);   					// set R21h, the vertical component of the Adress Counter (AC)
    write8_a1(y0 >> 8);					// set the vertical starting position to y0
    write8_a1(y0 & 0x00FF);
#endif
}

//==============================================================
// writeDisplay()
// // this function fills in the block of frame memory (GRAM) defined
// by the current values of SC (HSA), EC (HEA), SP (VSA), and EP (VEA)
// with the color values stored in the array "bitmap" (size N). If bitmap
// is a NULL pointer, the function fills the first N pixels of this
// memory block with the value "color"
// Arguments:
//      *bitmap - pointer to array containing color data (16-bit vlaues)
// 		color -  16-bit color value
//		N - size of the bitmap array or number of times color should be writen to the display
//==============================================================
void writeDisplay(uint16 *pBitmap, uint16 color, int N)
{
#ifdef ILI9341
	write8_a0(0x2C);						// send Memory Write command
#endif
#ifdef ILI9225
	write8_a0(0x22);				    	// send Write Data to GRAM instruction
#endif
	int i;
	if (pBitmap != NULL)
	{
		for (i=0; i<N; i++)
		{
			write8_a1(pBitmap[i] >> 8); 		// write bitmap[i] color to pixel (MSB first)
			write8_a1(pBitmap[i] & 0x00FF); 
		}
     }
	else
	{
		for (i=0; i<N; i++)
		{
			write8_a1(color >> 8); 			// write color to pixel (MSB first)
			write8_a1(color  & 0x00FF); 
		}
	}
}

/* [] END OF FILE */

